@@ -1,9 +1,9 @@
 /*
- * CU sudo version 1.5 (based on Root Group sudo version 1.1)
+ * CU sudo version 1.5.1 (based on Root Group sudo version 1.1)
  *
  * This software comes with no waranty whatsoever, use at your own risk.
  *
- * Please send bugs, changes, problems to sudo-bugs@cs.colorado.edu
+ * Please send bugs, changes, problems to sudo-bugs@courtesan.com
  *
  */
 
@@ -36,7 +36,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Id: check.c,v 1.110 1996/08/17 23:25:40 millert Exp $";
+static char rcsid[] = "$Id: check.c,v 1.116 1996/09/08 00:21:42 millert Exp $";
 #endif /* lint */
 
 #include "config.h"
@@ -151,8 +151,10 @@ void check_user()
 
     rtn = check_timestamp();
     if (rtn && user_uid) {	/* if timestamp is not current... */
+#ifndef NO_MESSAGE
 	if (rtn == 2)
 	    reminder();		/* do the reminder if ticket file is new */
+#endif /* NO_MESSAGE */
 	check_passwd();
     }
 
@@ -478,7 +480,7 @@ static void check_passwd()
 	pass = (char *) getpass(prompt);
 #  endif /* HAVE_KERB4 */
 #else
-	pass = tgetpass(prompt, PASSWORD_TIMEOUT * 60);
+	pass = tgetpass(prompt, PASSWORD_TIMEOUT * 60, user_name, shost);
 #endif /* USE_GETPASS */
 
 	/* Exit loop on nil password */
@@ -694,7 +696,7 @@ static char *sudo_skeyprompt(user_skey, p)
 
 #ifdef LONG_SKEY_PROMPT
     /* separate s/key challenge and prompt for easy snarfing */
-    (void) printf("key %d %s\n", user_skey->n - 1, user_skey->seed);
+    (void) fprintf(stderr, "key %d %s\n", user_skey->n - 1, user_skey->seed);
 
     /* return old prompt unmolested */
     return(p);
@@ -731,6 +733,7 @@ static char *sudo_skeyprompt(user_skey, p)
 #endif /* HAVE_SKEY */
 
 
+#ifndef NO_MESSAGE
 /********************************************************************
  *
  *  reminder()
@@ -744,7 +747,7 @@ static void reminder()
     (void) fprintf(stderr, "\n%s\n%s\n\n%s\n%s\n\n",
 #else
     (void) fprintf(stderr, "\n%s\n%s\n%s\n%s\n\n%s\n%s\n\n%s\n%s\n\n",
-	"    CU sudo version 1.5, based on Root Group sudo version 1.1",
+	"    CU sudo version 1.5.1, based on Root Group sudo version 1.1",
 	"    sudo version 1.1, Copyright (C) 1991 The Root Group, Inc.",
 	"    sudo comes with ABSOLUTELY NO WARRANTY.  This is free software,",
 	"    and you are welcome to redistribute it under certain conditions.",
@@ -757,3 +760,4 @@ static void reminder()
     
     (void) fflush(stderr);
 }
+#endif /* NO_MESSAGE */
