@@ -1,9 +1,9 @@
 /*
- * CU sudo version 1.5 (based on Root Group sudo version 1.1)
+ * CU sudo version 1.5.1 (based on Root Group sudo version 1.1)
  *
  * This software comes with no waranty whatsoever, use at your own risk.
  *
- * Please send bugs, changes, problems to sudo-bugs@cs.colorado.edu
+ * Please send bugs, changes, problems to sudo-bugs@courtesan.com
  *
  */
 
@@ -47,11 +47,11 @@
  *   However, due to the fact that both of the above are no longer
  *   working at Root Group, I am maintaining the "CU version" of
  *   sudo.
- *		Todd Miller  <Todd.Miller@cs.colorado.edu>
+ *		Todd Miller  <Todd.Miller@courtesan.com>
  */
 
 #ifndef lint
-static char rcsid[] = "$Id: sudo.c,v 1.167 1996/08/25 17:27:36 millert Exp $";
+static char rcsid[] = "$Id: sudo.c,v 1.171 1996/09/08 00:21:42 millert Exp $";
 #endif /* lint */
 
 #define MAIN
@@ -145,12 +145,14 @@ char *runas_user = "root";
 char *cmnd = NULL;
 char *cmnd_args = NULL;
 char *tty = NULL;
-char *prompt = PASSPROMPT;
+char *prompt;
 char host[MAXHOSTNAMELEN + 1];
 char *shost;
 char cwd[MAXPATHLEN + 1];
 struct stat cmnd_st;
+#ifdef SHELL_SETS_HOME
 static char *runas_homedir = NULL;
+#endif /* SHELL_SETS_HOME */
 extern struct interface *interfaces;
 extern int num_interfaces;
 extern int printmatches;
@@ -204,6 +206,12 @@ int main(argc, argv)
 	exit(1);
     }
 
+    /*
+     * set the prompt based on $SUDO_PROMPT (can be overridden by `-p')
+     */
+    if ((prompt = getenv("SUDO_PROMPT")) == NULL)
+	prompt = PASSPROMPT;
+
     /*
      * parse our arguments
      */
@@ -324,9 +332,11 @@ int main(argc, argv)
 	    /* become specified user or root */
 	    set_perms(PERM_RUNAS);
 
+#ifdef SHELL_SETS_HOME
 	    /* set $HOME for `sudo -s' */
 	    if ((sudo_mode & MODE_SHELL) && runas_homedir)
 		(void) sudo_setenv("HOME", runas_homedir);
+#endif /* SHELL_SETS_HOME */
 
 #ifndef PROFILING
 	    if ((sudo_mode & MODE_BACKGROUND) && fork() > 0) {
@@ -901,8 +911,9 @@ void set_perms(perm)
 					perror("");
 					exit(1);
 				    }
-
+#ifdef SHELL_SETS_HOME
 				    runas_homedir = pw_ent->pw_dir;
+#endif /* SHELL_SETS_HOME */
 				}
 
 				break;
