@@ -1,9 +1,9 @@
 /*
- * CU sudo version 1.5 (based on Root Group sudo version 1.1)
+ * CU sudo version 1.5.1 (based on Root Group sudo version 1.1)
  *
  * This software comes with no waranty whatsoever, use at your own risk.
  *
- * Please send bugs, changes, problems to sudo-bugs@cs.colorado.edu
+ * Please send bugs, changes, problems to sudo-bugs@courtesan.com
  *
  */
 
@@ -25,7 +25,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- *  $Id: sudo.h,v 1.108 1996/08/17 23:21:24 millert Exp $
+ *  $Id: sudo.h,v 1.111 1996/09/08 00:21:42 millert Exp $
  */
 
 #ifndef _SUDO_SUDO_H
@@ -195,7 +195,7 @@ int putenv		__P((const char *));
 #endif
 char *sudo_goodpath	__P((const char *));
 int sudo_setenv		__P((char *, char *));
-char *tgetpass		__P((char *, int));
+char *tgetpass		__P((char *, int, char *, char *));
 char * find_path	__P((char *));
 void log_error		__P((int));
 void inform_user	__P((int));
