@@ -1,5 +1,5 @@
 /*
- *  CU sudo version 1.5
+ *  CU sudo version 1.5.1
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- *  Please send bugs, changes, problems to sudo-bugs@cs.colorado.edu
+ *  Please send bugs, changes, problems to sudo-bugs@courtesan.com
  *
  *******************************************************************
  *
@@ -27,7 +27,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Id: tgetpass.c,v 1.44 1996/08/17 23:25:40 millert Exp $";
+static char rcsid[] = "$Id: tgetpass.c,v 1.47 1996/09/08 00:21:42 millert Exp $";
 #endif /* lint */
 
 #include "config.h"
@@ -90,9 +90,11 @@ static char rcsid[] = "$Id: tgetpass.c,v 1.44 1996/08/17 23:25:40 millert Exp $"
  *  and input will time out based on the value of timeout.
  */
 
-char * tgetpass(prompt, timeout)
+char * tgetpass(prompt, timeout, user, host)
     const char *prompt;
     int timeout;
+    char *user;
+    char *host;
 {
 #ifdef HAVE_TERMIOS_H
     struct termios term;
@@ -114,6 +116,7 @@ char * tgetpass(prompt, timeout)
     static char buf[_PASSWD_LEN + 1];
     fd_set readfds;
     struct timeval tv;
+    char *p;
 
     /*
      * mask out SIGINT and SIGTSTP, should probably just catch and deal.
@@ -165,7 +168,25 @@ char * tgetpass(prompt, timeout)
 #endif /* HAVE_TERMIOS_H */
 
     /* print the prompt */
-    (void) fputs(prompt, output);
+    if (prompt) {
+	p = (char *) prompt;
+	do {
+	    /* expand %u -> username, %h -> host */
+	    switch (*p) {
+		case '%':   if (user && *(p+1) == 'u') {
+				(void) fputs(user, output);
+				p++;
+				break;
+			    } else if (host && *(p+1) == 'h') {
+				(void) fputs(host, output);
+				p++;
+				break;
+			    }
+
+		default:    (void) fputc(*p, output);
+	    }
+	} while (*(++p));
+    }
 
     /* rewind if necesary */
     if (input == output) {
